@@ -37,6 +37,7 @@ from __future__ import absolute_import
 
 __author__ = "czerwin@scalyr.com"
 
+import platform
 import traceback
 import errno
 import gc
@@ -44,6 +45,7 @@ import os
 import sys
 import time
 import re
+import argparse
 import ssl
 from io import open
 
@@ -64,13 +66,11 @@ try:
     from __scalyr__ import scalyr_init
     from __scalyr__ import INSTALL_TYPE
     from __scalyr__ import DEV_INSTALL
-    from __scalyr__ import MSI_INSTALL
 except ImportError:
     from scalyr_agent.__scalyr__ import SCALYR_VERSION
     from scalyr_agent.__scalyr__ import scalyr_init
     from scalyr_agent.__scalyr__ import INSTALL_TYPE
     from scalyr_agent.__scalyr__ import DEV_INSTALL
-    from scalyr_agent.__scalyr__ import MSI_INSTALL
 
 # We must invoke this since we are an executable script.
 scalyr_init()
@@ -120,6 +120,7 @@ from scalyr_agent.platform_controller import (
 )
 from scalyr_agent.platform_controller import AgentNotRunning
 from scalyr_agent.build_info import get_build_revision
+from scalyr_agent import config_main
 from scalyr_agent import compat
 import scalyr_agent.monitors_manager
 
@@ -2115,24 +2116,55 @@ class WorkerThread(object):
 
 if __name__ == "__main__":
     my_controller = PlatformController.new_platform()
-    parser = OptionParser(
-        usage="Usage: scalyr-agent-2 [options] (start|stop|status|restart|condrestart|version)",
-        version="scalyr-agent v" + SCALYR_VERSION,
+
+    commands = [
+        "start",
+        "stop",
+        "status",
+        "restart",
+        "condrestart",
+        "version",
+        "config",
+    ]
+
+    if platform.system() == "Windows":
+        # If this is Windows, then also add service option.
+        # Using this option we can use windows executable as a base for the Windows Agent service.
+        # It has to save us from building multiple frozen binaries, when packaging.
+        commands.append("service")
+
+    # Create a special parser that does not print anything on error.
+    # This is needed to parse first positional argument and to decide which parser to use next.
+    # for example scalyr-agent-config parser or windows service.
+    # Also that is needed because we have to keep old behaviour of the script
+    # and when theres no any arguments, to show usage for the agent_main script.
+    class ErrorSilentParser(argparse.ArgumentParser):
+        def error(self, message):
+            pass
+
+    # Create parser that only has to parse first positional argument - our main command.
+    command_parser = ErrorSilentParser(
+        add_help=False,
     )
-    parser.add_option(
+    command_parser.add_argument("command", choices=commands)
+
+    # Also create parser for the agent command line.
+    parser = argparse.ArgumentParser()
+
+    parser.add_argument(
         "-c",
         "--config-file",
         dest="config_filename",
         help="Read configuration from FILE",
         metavar="FILE",
     )
-    parser.add_option(
+    parser.add_argument(
         "--extra-config-dir",
         default=None,
         help="An extra directory to check for configuration files",
         metavar="PATH",
     )
-    parser.add_option(
+    parser.add_argument(
         "-q",
         "--quiet",
         action="store_true",
@@ -2140,7 +2172,7 @@ if __name__ == "__main__":
         default=False,
         help="Only print error messages when running the start, stop, and condrestart commands",
     )
-    parser.add_option(
+    parser.add_argument(
         "-v",
         "--verbose",
         action="store_true",
@@ -2148,7 +2180,7 @@ if __name__ == "__main__":
         default=False,
         help="For status command, prints detailed information about running agent.",
     )
-    parser.add_option(
+    parser.add_argument(
         "-H",
         "--health_check",
         action="store_true",
@@ -2156,23 +2188,21 @@ if __name__ == "__main__":
         default=False,
         help="For status command, prints health check status. Return code will be 0 for a passing check, and 2 for failing",
     )
-    parser.add_option(
+    parser.add_argument(
         "--format",
         dest="status_format",
         default="text",
         help="Format to use (text / json) for the agent status command.",
     )
 
-    parser.add_option(
-        "",
+    parser.add_argument(
         "--no-fork",
         action="store_true",
         dest="no_fork",
         default=False,
         help="For the run command, does not fork the program to the background.",
     )
-    parser.add_option(
-        "",
+    parser.add_argument(
         "--no-check-remote-server",
         action="store_true",
         dest="no_check_remote",
@@ -2183,34 +2213,33 @@ if __name__ == "__main__":
     )
     my_controller.add_options(parser)
 
-    (options, args) = parser.parse_args()
-    my_controller.consume_options(options)
+    # Parse the main command by command parser.
+    command_args, other_argv = command_parser.parse_known_args()
 
-    if len(args) < 1:
-        print(
-            'You must specify a command, such as "start", "stop", or "status".',
-            file=sys.stderr,
-        )
-        parser.print_help(sys.stderr)
-        sys.exit(1)
-    elif len(args) > 1:
-        print(
-            'Too many commands specified.  Only specify one of "start", "stop", "status".',
-            file=sys.stderr,
-        )
-        parser.print_help(sys.stderr)
-        sys.exit(1)
-    elif args[0] not in (
-        "start",
-        "stop",
-        "status",
-        "restart",
-        "condrestart",
-        "version",
-    ):
-        print('Unknown command given: "%s"' % args[0], file=sys.stderr)
-        parser.print_help(sys.stderr)
-        sys.exit(1)
+    # If command is not specified, then we just print usage of the this script.
+    if command_args.command is None:
+        parser.print_help(file=sys.stderr)
+        exit(1)
+
+    if command_args.command == "service":
+        # Windows specific command that tell to start Agent's Windows service.
+        from scalyr_agent import platform_windows
+
+        # Create fully valid command line args so the Windows service could handle it properly.
+        argv = [sys.argv[0]]
+        argv.extend(other_argv)
+        platform_windows.parse_options(argv)
+        exit(0)
+
+    if command_args.command == "config":
+        # Add the config option. So we can configure the agent from the same executable.
+        # It has to save us from building multiple frozen binaries, when packaging.
+        config_main.parse_config_options(other_argv)
+        exit(0)
+
+    options = parser.parse_args(args=other_argv)
+
+    my_controller.consume_options(options)
 
     if options.config_filename is not None and not os.path.isabs(
         options.config_filename
@@ -2220,7 +2249,7 @@ if __name__ == "__main__":
     main_rc = 1
     try:
         main_rc = ScalyrAgent(my_controller).main(
-            options.config_filename, args[0], options
+            options.config_filename, command_args.command, options
         )
     except Exception as mainExcept:
         print(six.text_type(mainExcept), file=sys.stderr)
