@@ -89,8 +89,8 @@ define_config_option(
     __monitor__,
     "container_name",
     "Optional (defaults to None). Defines a regular expression that matches the name given to the "
-    "container running the scalyr-agent.\n"
-    "If this is None, the scalyr agent will look for a container running /usr/sbin/scalyr-agent-2 as the main process.\n",
+    "container running the scalyr-agent."
+    "If this is None, the scalyr agent will look for a container running /usr/sbin/scalyr-agent-2 as the main process.",
     convert_to=six.text_type,
     default=None,
 )
@@ -109,8 +109,8 @@ define_config_option(
     "api_socket",
     "Optional (defaults to /var/scalyr/docker.sock). Defines the unix socket used to communicate with "
     "the docker API.   WARNING, if you have `mode` set to `syslog`, you must also set the "
-    "`docker_api_socket` configuration option in the syslog monitor to this same value\n"
-    "Note:  You need to map the host's /run/docker.sock to the same value as specified here, using the -v parameter, e.g.\n"
+    "`docker_api_socket` configuration option in the syslog monitor to this same value."
+    "Note:  You need to map the host's /run/docker.sock to the same value as specified here, using the -v parameter, e.g."
     "\tdocker run -v /run/docker.sock:/var/scalyr/docker.sock ...",
     convert_to=six.text_type,
     default="/var/scalyr/docker.sock",
@@ -121,7 +121,7 @@ define_config_option(
     "docker_api_version",
     "Optional (defaults to 'auto'). The version of the Docker API to use.  WARNING, if you have "
     "`mode` set to `syslog`, you must also set the `docker_api_version` configuration option in the "
-    "syslog monitor to this same value\n",
+    "syslog monitor to this same value.",
     convert_to=six.text_type,
     default="auto",
     env_aware=True,
@@ -149,7 +149,7 @@ define_config_option(
 define_config_option(
     __monitor__,
     "max_previous_lines",
-    "Optional (defaults to 5000). The maximum number of lines to read backwards from the end of the stdout/stderr logs\n"
+    "Optional (defaults to 5000). The maximum number of lines to read backwards from the end of the stdout/stderr logs."
     "when starting to log a containers stdout/stderr to find the last line that was sent to Scalyr.",
     convert_to=int,
     default=5000,
@@ -158,7 +158,7 @@ define_config_option(
 define_config_option(
     __monitor__,
     "readback_buffer_size",
-    "Optional (defaults to 5k). The maximum number of bytes to read backwards from the end of any log files on disk\n"
+    "Optional (defaults to 5k). The maximum number of bytes to read backwards from the end of any log files on disk."
     "when starting to log a containers stdout/stderr.  This is used to find the most recent timestamp logged to file "
     "was sent to Scalyr.",
     convert_to=int,
@@ -195,7 +195,7 @@ define_config_option(
     __monitor__,
     "metrics_only",
     "Optional (defaults to False). If true, the docker monitor will only log docker metrics and not any other information "
-    "about running containers.  If set to true, this value overrides the config item 'report_container_metrics'\n",
+    "about running containers.  If set to true, this value overrides the config item 'report_container_metrics'.",
     convert_to=bool,
     default=False,
     env_aware=True,
@@ -292,7 +292,7 @@ define_config_option(
 define_config_option(
     __monitor__,
     "log_timestamps",
-    "Optional (defaults to True). If true, stdout/stderr logs for logs consumed via Docker API (docker_raw_logs: false) will contain docker timestamps at the beginning of the line\n",
+    "Optional (defaults to True). If true, stdout/stderr logs for logs consumed via Docker API (docker_raw_logs: false) will contain docker timestamps at the beginning of the line.",
     convert_to=bool,
     default=True,
 )
@@ -1219,7 +1219,7 @@ class ContainerChecker(StoppableThread):
                             )
 
                 self.raw_logs[:] = [
-                    l for l in self.raw_logs if l["cid"] not in stopping
+                    line for line in self.raw_logs if line["cid"] not in stopping
                 ]
             else:
                 for logger in self.docker_loggers:
@@ -1231,11 +1231,11 @@ class ContainerChecker(StoppableThread):
                             )
 
                 self.docker_loggers[:] = [
-                    l for l in self.docker_loggers if l.cid not in stopping
+                    line for line in self.docker_loggers if line.cid not in stopping
                 ]
 
             self.docker_logs[:] = [
-                l for l in self.docker_logs if l["cid"] not in stopping
+                line for line in self.docker_logs if line["cid"] not in stopping
             ]
 
     def __start_loggers(self, starting):
